# -*- coding: utf-8 -*-
# This software is distributed under the two-clause BSD license.

from .server import LdapServer, TLSConfig
from .version import VERSION as __version__

LOCALHOST_TLS_CONFIG = TLSConfig(
    root="""-----BEGIN CERTIFICATE-----
MIIDxDCCAqygAwIBAgIJAI76MjayHI8pMA0GCSqGSIb3DQEBCwUAMDIxIjAgBgNV
BAMMGVNlbGYtc2lnbmVkIGxvY2FsIENBIFJvb3QxDDAKBgNVBAsMA0RldjAeFw0x
OTA1MTUxMTA5MzdaFw0yOTA1MTIxMTA5MzdaMDIxIjAgBgNVBAMMGVNlbGYtc2ln
bmVkIGxvY2FsIENBIFJvb3QxDDAKBgNVBAsMA0RldjCCASIwDQYJKoZIhvcNAQEB
BQADggEPADCCAQoCggEBAMIpgtsshv7yxm/KXecT/5oA6fZGD9kTVMORk9M/OU9E
QY8BKpfiC4Tw1ZJ6LUYS3NUfP7pa3eNXRBomBGoy64zlQUFLOUc3XWpp2hEL72kV
AHJcd5L0NdlUvcIetAN2A1M8bMi/ZrYGPwLohWyFinAsQ52RDpd8mwvSJwRiykAi
zWagx+pwvmW7VIV5yjc6dDuyFXFnAdLVwhN6BQQLSxQEFKfhlPNqDAf9vpuq58WS
n3aOlGo8Csrj30tstuUfz4B3GkbhU7IOskWyM2I33DvMITA2Hy2M2CAueBxah8pB
IWVt969DVHFoQVNwJJtjRjkNW3HJW+YSkjFPHfwIyjUCAwEAAaOB3DCB2TASBgNV
HRMBAf8ECDAGAQH/AgEBMA4GA1UdDwEB/wQEAwIBBjAdBgNVHQ4EFgQUwlV/AdlB
ClVA/FzXApBiLeEwwkkwYgYDVR0jBFswWYAUwlV/AdlBClVA/FzXApBiLeEwwkmh
NqQ0MDIxIjAgBgNVBAMMGVNlbGYtc2lnbmVkIGxvY2FsIENBIFJvb3QxDDAKBgNV
BAsMA0RldoIJAI76MjayHI8pMDAGA1UdHgQpMCegJTARgg8udm9sYXRpbGRhcC5v
cmcwEIIOdm9sYXRpbGRhcC5vcmcwDQYJKoZIhvcNAQELBQADggEBABUFWxgO4Lkv
Md2AKbMEKnwb25ZXqEf/K6F8sfJPRV5vH3eSOCKBEOt2E3RgdleR643vHfOSnKwQ
BMs7V/Vy5LYBL52M1k9UfQxajxWSmMQSxyFvK8mF9y09TahqewheqDue2LPJkMKR
GnGGSYE1IB5phU80UW7cGoRNmZEWVMgo+DScfwikcDTrE2VwyCQBHxQDTX0u48SS
mvuF62QnmOmoud7RqGsORIE/7eO8rcFoOkPO4jMNpCXOYEhRXWnyApSdXLQ3VeVV
CjGiEP9qLV3lhhkgGcPZzimLrV7hK75hPFqNFPoKjrVLl6P3WdokKA/h0Ok1VCTG
dMUH50jvlt0=
-----END CERTIFICATE-----
""",
    chain=[
        """-----BEGIN CERTIFICATE-----
MIIDvDCCAqSgAwIBAgIBAjANBgkqhkiG9w0BAQsFADAyMSIwIAYDVQQDDBlTZWxm
LXNpZ25lZCBsb2NhbCBDQSBSb290MQwwCgYDVQQLDANEZXYwHhcNMTkwNTE1MTEw
OTM3WhcNMjkwNTEyMTEwOTM3WjAyMSIwIAYDVQQDDBlTZWxmLXNpZ25lZCBsb2Nh
bCBDQSBSb290MQwwCgYDVQQLDANEZXYwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw
ggEKAoIBAQDLwI/12ZVK3XbWajn/p7LNQW/7Za5WKsYoAXmW/NLEj5fQvAFfuy9k
ur6LW1MR7bfq6fX5tMZNvAlK2o6GYtbRhE1n7ZEEUkMjVl2kwFCjbI6NAJ9s8YAd
hldekxc68mnS26VHPBOG2CwRGj8bIRZK5Hm1NGcMtLFFqmT5t+tmVaJdTBBnoxb1
4YMXU35Ltf/RXxzKG9/RQZ5jV4OzZRs22veccBcYIOuhLS0vR24Qr8mekjkpju2j
XcSbIPuUBZ3FJHUGTPCXPhTbwwCCCGXE+h+Yh7x0rFTBsObjcRCcG0jTwaEpoAZ2
483daT2cM2ms1HTD2Qz5LXp/SrHpE1y9AgMBAAGjgdwwgdkwEgYDVR0TAQH/BAgw
BgEB/wIBADAOBgNVHQ8BAf8EBAMCAQYwHQYDVR0OBBYEFDK21gwaeINTyWPY2dQ5
pCiHYkrWMGIGA1UdIwRbMFmAFMJVfwHZQQpVQPxc1wKQYi3hMMJJoTakNDAyMSIw
IAYDVQQDDBlTZWxmLXNpZ25lZCBsb2NhbCBDQSBSb290MQwwCgYDVQQLDANEZXaC
CQCO+jI2shyPKTAwBgNVHR4EKTAnoCUwEYIPLnZvbGF0aWxkYXAub3JnMBCCDnZv
bGF0aWxkYXAub3JnMA0GCSqGSIb3DQEBCwUAA4IBAQAac3Ep3WkrQqUCtUAOBxYa
kv1v+U7RvRkJOYVOXccF93d1KKn0TxQFYgddewkEY+HVzMiJbsdSLj5qSqMV8A2m
hzU9Av/K3b7r1VBRGvzwH5moa15WZEB5KfnPIbhtdPTfJ/RHEtEChkXAtOynhhNU
hOwZKicbGvm7Lo1ppFGoLyxuPDxfpVslwtsxEUWYR9grkME/lro5XXjxOqv6QwVM
qZuheGEe9J/gqr7ImnUkjpOfHc91J80qrfeNh01WMQD7JQft2zAVPLZCzPt8cx0b
C2DEMEYWZYoFG8FBn0lb2hs4SvpvEpxpo2jKcKCvUD7OyZl9bU8Nvly3SinVBzUT
-----END CERTIFICATE-----
""",
    ],
    certificate="""-----BEGIN CERTIFICATE-----
MIIDBTCCAe2gAwIBAgIBAjANBgkqhkiG9w0BAQsFADAyMSIwIAYDVQQDDBlTZWxm
LXNpZ25lZCBsb2NhbCBDQSBSb290MQwwCgYDVQQLDANEZXYwHhcNMTkwNTE1MTEw
OTM3WhcNMjkwNTEyMTEwOTM3WjAxMSEwHwYDVQQDDBhsb2NhbGhvc3Qudm9sYXRp
bGRhcC5vcmcxDDAKBgNVBAsMA0RldjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC
AQoCggEBANlRIzf3HibjTXowkmoVGBFiZsEMS2nYlQr/D3RCTydhzQ8k/c7fYYS/
FOJD5TVnJ9lGUv1VmD8Uad18m+nuyYimtDDhZK4ya5roVVwzywZMfF5IKI9iqbed
4IsJjkByItW1q7tz7TRoxStkWa0XG/xdRDBOAltWuPLAejxwNO9RaijcXoath7dp
MmsrgE6567+gf9QZ3bNadr+C/926134ChAdxFe4IKYdCxKg2GdINQx6myS8HHUT6
sf9txaFZVYkqOFC5T8MpZ11fDRl0P6blkBQdQCdooPFi7zCEtwUefxjuTxDWTkoM
CUl5eOxbYxQwbUuJyKjOMqRnyM4paSsCAwEAAaMnMCUwIwYDVR0RBBwwGoIYbG9j
YWxob3N0LnZvbGF0aWxkYXAub3JnMA0GCSqGSIb3DQEBCwUAA4IBAQBXVkLr6krL
psQjZq7x6ODZFK0Hvs5Xbt1nA2Ib09j+5h3t39Eu4k+p+XUYVniuAhnijNQ4pl7I
xeEl6s6hXiYrMD6y7+F3Hhqn7uW2We/Ptu6r+iKN4aVs19Od6HftmOxFtM6idhd5
ExY29ID1kZpJ9GygcOWh7EiY9BgVMMj/Oy/wmIFP9zaPATbms17zgXCrnhmeyqCM
F+01SLza+Xw+K5Q327qVd1xkePVXC0iUwQLY/N+0j24QcfCeNeE7fCT19UruYQ+g
Vv8JBsuMSOyXPDdfWG6csFoP8gkU44n+KkRT9lZF27jzcwbS85FjaHwQOqiEuUnN
jflWAqV1w0bP
-----END CERTIFICATE-----
""",
    key="""-----BEGIN PRIVATE KEY-----
MIIEvgIBADANBgkqhkiG9w0BAQEFAASCBKgwggSkAgEAAoIBAQDZUSM39x4m4016
MJJqFRgRYmbBDEtp2JUK/w90Qk8nYc0PJP3O32GEvxTiQ+U1ZyfZRlL9VZg/FGnd
fJvp7smIprQw4WSuMmua6FVcM8sGTHxeSCiPYqm3neCLCY5AciLVtau7c+00aMUr
ZFmtFxv8XUQwTgJbVrjywHo8cDTvUWoo3F6GrYe3aTJrK4BOueu/oH/UGd2zWna/
gv/dutd+AoQHcRXuCCmHQsSoNhnSDUMepskvBx1E+rH/bcWhWVWJKjhQuU/DKWdd
Xw0ZdD+m5ZAUHUAnaKDxYu8whLcFHn8Y7k8Q1k5KDAlJeXjsW2MUMG1LiciozjKk
Z8jOKWkrAgMBAAECggEAUiz6Ullhz3a4f3IKi466cShyjqFlivrZMTVN1LqWT+AN
uKJWT3ns2FOhRAZEkDMXwHN1QlKxpXjEp3pNQuKG1uOi07EHb0+lnQgp7xmutg0K
ImTK4Z1/a+2JUUolvnzqa0GtVM77bYwIsuXZezh33rAt7s4w2fUrLrBWCLCtc6j1
ItWAHXBrdD9eEDJ4l97Zm6Ne8WMA1sIv4zOOCgbtYd9RcB0S7fjKemlRX/lMkjcN
QDDoAwePanqQkceGy0h9AgJ/n4d1bKl5tE4waqqTm6XYkkEd7A5ZA78izoEZhzci
H1IRUT085LU4L1I1Hk8NGFdIQ8giKtG+3zgnsYeekQKBgQD1i9I7Jn2G7lvJ0oJu
GuR/dS2M1F5oXOp4SxFITqfw7rcLpEd4wjeF2wjHZFQyiwMzakbtvBoj4rlYv+KK
3F7CqH3zTkbBvoxYEBOLF/D2WkDZosgYSsB7psMrJ+7jqCg7tn8hDTub4Ar8cEzd
6e1JfefVw92R+TEhihcF8gf55QKBgQDikaY3QwKFVYMlyS+E7L9yLIXjebCRcBuC
Bmn6MTRq4TnK08aZhi92/jqR7Bxy3M8FJ7Kj741atqGtFWVqYfuVROE5sACVXy2o
C3O/EYjseJKSHwFQogqJ96wIPIaekrvH+glcInxIp8GSreMc37ghppnnbrYMYoK/
u65sxbNlzwKBgQDzZjprL+hWjIioMuffxQCj57/TTeCXiyNRQvhKuM144ujHvXyr
k7n+EfVN0YI059+wY7UTi9ZNpD0eYHdsNq4oP2U6fWlePEhaMvVsd7sAOM737Yhz
rAXJjLECYn9HZDUdm/XBCaEBDsFVIuzPPUdeBlR9bb6BKIcvO/c+iYCmkQKBgADw
uc/g51HGWRT/EMNseB7xMF0RVDpGTNbtT+NJ8P3AkYzV9C0O8YN86qFQaY3QfMt4
rrUfeWa2+1TMke8vGOw1rPmgUWBNVNMtuP1CBV914KXamxbKlWCdNomSNrzRvxXF
Y+SOABYNHDCPqDGmfA0ns9vSCc9jWUeSb9bjuyrhAoGBAME77wEd/3dhgk8iX6zz
b0+wWOBz+CqBBLD8hs/N2/Sj8Cwactebi0sRZqgc5HAVUsUC2OV+mUovUzQpcMou
qVFgjUBT72YMkEqZsKVdiI2+A9YjWYwKka1dllIFaZG7CbiyCI5We2Qv4P7N0GY8
+9LOsFxClEOIHKHjIFTMNnfL
-----END PRIVATE KEY-----
""",
)
